==> parcel-bundler-vue-1.6.3.tgz: package/lib/assets/TypeScriptAsset.js <==
'use strict';

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _get2 = require('babel-runtime/helpers/get');

var _get3 = _interopRequireDefault(_get2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var JSAsset = require('./JSAsset');
var localRequire = require('../utils/localRequire');

var TypeScriptAsset = function (_JSAsset) {
  (0, _inherits3.default)(TypeScriptAsset, _JSAsset);

  function TypeScriptAsset() {
    (0, _classCallCheck3.default)(this, TypeScriptAsset);
    return (0, _possibleConstructorReturn3.default)(this, (TypeScriptAsset.__proto__ || (0, _getPrototypeOf2.default)(TypeScriptAsset)).apply(this, arguments));
  }

  (0, _createClass3.default)(TypeScriptAsset, [{
    key: 'install',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.t0 = [];
                _context.t1 = _toConsumableArray3.default;
                _context.next = 4;
                return (0, _get3.default)(TypeScriptAsset.prototype.__proto__ || (0, _getPrototypeOf2.default)(TypeScriptAsset.prototype), 'install', this).call(this);

              case 4:
                _context.t2 = _context.sent;
                _context.t3 = (0, _context.t1)(_context.t2);
                _context.t4 = [{ name: 'typescript', dev: true }];
                return _context.abrupt('return', _context.t0.concat.call(_context.t0, _context.t3, _context.t4));

              case 8:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function install() {
        return _ref.apply(this, arguments);
      }

      return install;
    }()
  }, {
    key: 'parse',
    value: function () {
      var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(code) {
        var typescript, transpilerOptions, tsconfig, transpiled, content;
        return _regenerator2.default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.next = 2;
                return localRequire('typescript', this.name);

              case 2:
                typescript = _context2.sent;
                transpilerOptions = {
                  compilerOptions: {
                    module: typescript.ModuleKind.CommonJS,
                    jsx: typescript.JsxEmit.Preserve
                  },
                  fileName: this.relativeName
                };
                _context2.next = 6;
                return this.getConfig(['tsconfig.json']);

              case 6:
                tsconfig = _context2.sent;


                // Overwrite default if config is found
                if (tsconfig) {
                  transpilerOptions.compilerOptions = (0, _assign2.default)(transpilerOptions.compilerOptions, tsconfig.compilerOptions);
                }
                transpilerOptions.compilerOptions.noEmit = false;
                transpilerOptions.compilerOptions.sourceMap = this.options.sourceMaps;

                // Transpile Module using TypeScript and parse result as ast format through babylon
                transpiled = typescript.transpileModule(code, transpilerOptions);

                this.sourceMap = transpiled.sourceMapText;

                if (this.sourceMap) {
                  this.sourceMap = JSON.parse(this.sourceMap);
                  this.sourceMap.sources = [this.relativeName];
                  this.sourceMap.sourcesContent = [this.contents];

                  // Remove the source map URL
                  content = transpiled.outputText;

                  transpiled.outputText = content.substring(0, content.lastIndexOf('//# sourceMappingURL'));
                }

                this.contents = transpiled.outputText;
                _context2.next = 16;
                return (0, _get3.default)(TypeScriptAsset.prototype.__proto__ || (0, _getPrototypeOf2.default)(TypeScriptAsset.prototype), 'parse', this).call(this, this.contents);

              case 16:
                return _context2.abrupt('return', _context2.sent);

              case 17:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function parse(_x) {
        return _ref2.apply(this, arguments);
      }

      return parse;
    }()
  }]);
  return TypeScriptAsset;
}(JSAsset);

module.exports = TypeScriptAsset;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/assets/TypeScriptAsset.js <==
'use strict';

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _get2 = require('babel-runtime/helpers/get');

var _get3 = _interopRequireDefault(_get2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var JSAsset = require('./JSAsset');
var localRequire = require('../utils/localRequire');

var TypeScriptAsset = function (_JSAsset) {
  (0, _inherits3.default)(TypeScriptAsset, _JSAsset);

  function TypeScriptAsset() {
    (0, _classCallCheck3.default)(this, TypeScriptAsset);
    return (0, _possibleConstructorReturn3.default)(this, (TypeScriptAsset.__proto__ || (0, _getPrototypeOf2.default)(TypeScriptAsset)).apply(this, arguments));
  }

  (0, _createClass3.default)(TypeScriptAsset, [{
    key: 'install',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.t0 = [];
                _context.t1 = _toConsumableArray3.default;
                _context.next = 4;
                return (0, _get3.default)(TypeScriptAsset.prototype.__proto__ || (0, _getPrototypeOf2.default)(TypeScriptAsset.prototype), 'install', this).call(this);

              case 4:
                _context.t2 = _context.sent;
                _context.t3 = (0, _context.t1)(_context.t2);
                _context.t4 = [{ name: 'typescript', dev: true }];
                return _context.abrupt('return', _context.t0.concat.call(_context.t0, _context.t3, _context.t4));

              case 8:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function install() {
        return _ref.apply(this, arguments);
      }

      return install;
    }()
  }, {
    key: 'parse',
    value: function () {
      var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(code) {
        var typescript, transpilerOptions, tsconfig;
        return _regenerator2.default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.next = 2;
                return localRequire('typescript', this.name);

              case 2:
                typescript = _context2.sent;
                transpilerOptions = {
                  compilerOptions: {
                    module: typescript.ModuleKind.CommonJS,
                    jsx: typescript.JsxEmit.Preserve
                  },
                  fileName: this.basename
                };
                _context2.next = 6;
                return this.getConfig(['tsconfig.json']);

              case 6:
                tsconfig = _context2.sent;


                // Overwrite default if config is found
                if (tsconfig) {
                  transpilerOptions.compilerOptions = (0, _assign2.default)(transpilerOptions.compilerOptions, tsconfig.compilerOptions);
                }
                transpilerOptions.compilerOptions.noEmit = false;

                // Transpile Module using TypeScript and parse result as ast format through babylon
                this.contents = typescript.transpileModule(code, transpilerOptions).outputText;
                _context2.next = 12;
                return (0, _get3.default)(TypeScriptAsset.prototype.__proto__ || (0, _getPrototypeOf2.default)(TypeScriptAsset.prototype), 'parse', this).call(this, this.contents);

              case 12:
                return _context2.abrupt('return', _context2.sent);

              case 13:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function parse(_x) {
        return _ref2.apply(this, arguments);
      }

      return parse;
    }()
  }]);
  return TypeScriptAsset;
}(JSAsset);

module.exports = TypeScriptAsset;
